Logic Functions
===============

.. https://docs.scipy.org/doc/numpy/reference/routines.logic.html

Truth value testing
-------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.all
   cupy.any
   cupy.in1d
   cupy.isin


Infinities and NaNs
-------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.isfinite
   cupy.isinf
   cupy.isnan


Array type testing
------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.iscomplex
   cupy.iscomplexobj
   cupy.isfortran
   cupy.isreal
   cupy.isrealobj
   cupy.isscalar


Logic operations
----------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.logical_and
   cupy.logical_or
   cupy.logical_not
   cupy.logical_xor


Comparison
----------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.allclose
   cupy.isclose
   cupy.greater
   cupy.greater_equal
   cupy.less
   cupy.less_equal
   cupy.equal
   cupy.not_equal
